{% extends "forms.html" %}
{% load forms %}


{% block title %}Invite new user{% endblock %}


{% block breadcrumbs %}
<div class="breadcrumbs">
    <a href='{% url "index" %}'>Home</a>&nbsp;›
    <a href="{% url 'kg_application_list' %}">Applications</a>&nbsp;›
    Start application
</div>
{% endblock %}

{% block content %}
<div class="module">
    <h2>Send invitation</h2>
    <form method="post" action=".">{% csrf_token %}
        {% if project %}
            <p>You will be inviting a new applicant to join the project
            '{{ project }}'.</p>
        {% else %}
            <p>You will be inviting a new applicant to join and select
            a project.</p>
        {% endif %}

        {% form_as_div form %}

        <p>Please confirm you want to start a new application.</p>
        <div class="submit-row">
            <input type="submit" value="Go" class="default" />
        </div>
    </form>
</div>
{% endblock %}
