{% extends "main.html" %}
{% load karaage_tags %}
{% load render_table from django_tables2 %}


{% block title %}Machine{% endblock %}


{% block breadcrumbs %}
<div class="breadcrumbs">
    <a href='{% url "index" %}'>Home</a>&nbsp;›
    <a href="{% url 'kg_machine_category_list' %}">Machines</a>&nbsp;›
    {{ machine_category }}
</div>
{% endblock %}


{% block content %}
<div id="content-main">
    <div class="module">
        <h2>Machine Category Details</h2>
        <h3>{{ machine_category.name }}</h3>
        {% render_table table %}
        {% if is_admin %}
        <div class="object-tools">
            <ul>
                <li><a href="{% url 'kg_machine_category_logs' machine_category.pk %}">Logs</a></li>
                <li><a href="{% url 'kg_machine_category_accounts' machine_category.pk %}">Accounts</a></li>
                <li><a href="{% url 'kg_machine_category_projects' machine_category.pk %}">Projects</a></li>
                <li><a href="{% url 'kg_machine_category_edit' machine_category.id %}" class="changelink">Edit category</a></li>
            </ul>
        </div>
        {% endif %}
    </div>

    {% for_each_app_include "machinecategory_detail_extra.html" %}

    {% if is_admin %}
    <div class="module">
        <h2>Comments</h2>
        {% comments machine_category %}
        <div class="object-tools">
            <ul>
                <li><a href="{% url 'kg_machine_category_add_comment' machine_category.pk %}" class="addlink">Add comment</a></li>
            </ul>
        </div>
    </div>
    {% endif %}
</div>
{% endblock %}
