{% load karaage_tags %}
{% load usage %}
{% load render_table from django_tables2 %}
{% get_project_recent_usage project as usage_list %}
<div class="module">
    <h2>Latest Usage</h2>
    {% render_table usage_list %}
    <div class="object-tools">
        <ul>
            <li><a href="{% url 'kg_usage_job_list' %}{% url_with_param project=project.pid %}">Display all jobs</a></li>
            {% for pc in project.projectquota_set.all %}<li><a href="{% url 'kg_usage_project' pc.machine_category.pk project.pid %}">Usage: {{ pc.machine_category }}</a></li>{% endfor %}
        </ul>
    </div>
</div>
