{% extends "forms.html" %}
{% load forms %}


{% block title %}Delete Project Quota/Cap{% endblock %}


{% block breadcrumbs %}
<div class="breadcrumbs">
    <a href='{% url "index" %}'>Home</a>&nbsp;›
    <a href="{% url 'kg_project_list' %}">Projects</a>&nbsp;›
    <a href="{% url 'kg_project_detail' project_chunk.project.id %}">{{ project_chunk.project.pid }}</a>&nbsp;›
    Delete Project Quota/Cap
</div>
{% endblock %}


{% block content %}
<div class="module">
    <h2>Project Caps/quota</h2>
    <div class="table-container">
        <table>
            <thead>
            <tr>
                <th>Machine Category</th>
                <th>Quota</th>
            </tr>
            </thead>
            <tbody>
            <tr>
                <td>{{ project_chunk.machine_category }}</td>
                <td>{{ project_chunk.get_cap }}</td>
            </tr>
            </tbody>
        </table>
    </div>
</div>

<form method="post" action=".">{% csrf_token %}
    <div class="submit-row">
        <input type="submit" value="Delete" class="default" />
    </div>
</form>
{% endblock %}
