{% extends "main.html" %}
{% load render_table from django_tables2 %}


{% block title %}Machine Accounts{% endblock %}


{% block breadcrumbs %}
<div class="breadcrumbs">
    <a href='{% url "index" %}'>Home</a>&nbsp;›
    <a href="{% url 'kg_machine_category_list' %}">Machines</a>&nbsp;›
    <a href="{% url 'kg_machine_category_detail' machine_category.pk %}">{{ machine_category }}</a>&nbsp;›
    Accounts
</div>
{% endblock %}


{% block content %}
<div id="content-main">
    <div class="module">
        <h2>Accounts in {{ machine_category }}</h2>
        {% render_table table %}
    </div>
</div>
{% endblock %}
